@@ -2,6 +2,7 @@ from .pipeline import (
     stage_1,
     stage_2,
     stage_3,
+    editor,  
     cleanup_pipeline,
     pretty_print_page_with_image,
     show_comparison_view
@@ -11,7 +12,8 @@ __all__ = [
     "stage_1",
     "stage_2",
     "stage_3",
+    "editor",  
     "cleanup_pipeline",
     "pretty_print_page_with_image",
     "show_comparison_view",
-]
\ No newline at end of file
+]
